package com.imuxuan.floatingview;

import android.app.Activity;
import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import com.imuxuan.floatingview.utils.EnContext;

public class FloatingView implements IFloatingView {
    private static volatile FloatingView mInstance;
    private FrameLayout mContainer;
    private EnFloatingView mEnFloatingView;

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView detach(Activity activity) {
        return this;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView detach(FrameLayout frameLayout) {
        return this;
    }

    private FloatingView() {
    }

    public static FloatingView get() {
        if (mInstance == null) {
            synchronized (FloatingView.class) {
                if (mInstance == null) {
                    mInstance = new FloatingView();
                }
            }
        }
        return mInstance;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView remove() {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            /* class com.imuxuan.floatingview.FloatingView.AnonymousClass1 */

            public void run() {
                if (FloatingView.this.mEnFloatingView != null) {
                    FloatingView.this.mContainer.removeView(FloatingView.this.mEnFloatingView);
                    FloatingView.this.mEnFloatingView = null;
                }
            }
        });
        return this;
    }

    private void ensureMiniPlayer(Context context) {
        synchronized (this) {
            if (this.mEnFloatingView != null) {
                this.mEnFloatingView.setVisibility(0);
                return;
            }
            this.mEnFloatingView = new EnFloatingView(context.getApplicationContext());
            this.mEnFloatingView.setLayoutParams(getParams());
            addViewToWindow(this.mEnFloatingView);
        }
    }

    public void setPos() {
        this.mEnFloatingView.setLayoutParams(getLandParams());
        this.mEnFloatingView.setPos();
        this.mEnFloatingView.requestLayout();
    }

    private FrameLayout.LayoutParams getLandParams() {
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-2, -2);
        layoutParams.gravity = 8388691;
        layoutParams.setMargins(213, layoutParams.topMargin, layoutParams.rightMargin, -333);
        return layoutParams;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView add() {
        ensureMiniPlayer(EnContext.get());
        return this;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView attach(Activity activity) {
        if (this.mContainer == null) {
            attach(getActivityRoot(activity));
        }
        return this;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView attach(FrameLayout frameLayout) {
        EnFloatingView enFloatingView;
        FrameLayout frameLayout2;
        if (frameLayout == null || (enFloatingView = this.mEnFloatingView) == null) {
            this.mContainer = frameLayout;
            return this;
        } else if (enFloatingView.getParent() == frameLayout) {
            return this;
        } else {
            if (this.mContainer != null && this.mEnFloatingView.getParent() == (frameLayout2 = this.mContainer)) {
                frameLayout2.removeView(this.mEnFloatingView);
            }
            this.mContainer = frameLayout;
            frameLayout.addView(this.mEnFloatingView);
            return this;
        }
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public EnFloatingView getView() {
        return this.mEnFloatingView;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView icon(int i) {
        EnFloatingView enFloatingView = this.mEnFloatingView;
        if (enFloatingView != null) {
            enFloatingView.setIconImage(i);
        }
        return this;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView layoutParams(ViewGroup.LayoutParams layoutParams) {
        EnFloatingView enFloatingView = this.mEnFloatingView;
        if (enFloatingView != null) {
            enFloatingView.setLayoutParams(layoutParams);
        }
        return this;
    }

    @Override // com.imuxuan.floatingview.IFloatingView
    public FloatingView listener(MagnetViewListener magnetViewListener) {
        EnFloatingView enFloatingView = this.mEnFloatingView;
        if (enFloatingView != null) {
            enFloatingView.setMagnetViewListener(magnetViewListener);
        }
        return this;
    }

    private void addViewToWindow(EnFloatingView enFloatingView) {
        FrameLayout frameLayout = this.mContainer;
        if (frameLayout != null) {
            frameLayout.addView(enFloatingView);
        }
    }

    private FrameLayout.LayoutParams getParams() {
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-2, -2);
        layoutParams.gravity = 8388691;
        layoutParams.setMargins(13, layoutParams.topMargin, layoutParams.rightMargin, 56);
        return layoutParams;
    }

    private FrameLayout getActivityRoot(Activity activity) {
        if (activity == null) {
            return null;
        }
        try {
            return (FrameLayout) activity.getWindow().getDecorView().findViewById(16908290);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }
}
