package com.tencent.liteav.audio;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import com.tencent.liteav.audio.impl.TXCTraeJNI;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.util.d;
import java.lang.ref.WeakReference;

public class TXCLiveBGMPlayer {
    private static final int PLAY_ERR_AUDIO_TRACK = -3;
    private static final int PLAY_ERR_AUDIO_TRACK_PLAY = -4;
    private static final int PLAY_ERR_FILE_NOTFOUND = -2;
    private static final int PLAY_ERR_OPEN = -1;
    private static final int PLAY_SUCCESS = 0;
    private static final String TAG = ("AudioCenter:" + TXCLiveBGMPlayer.class.getSimpleName());
    private static TXCLiveBGMPlayer instance;
    private Context mContext = null;
    private String mFilePath = null;
    private boolean mIsPause = false;
    private boolean mIsRunning = false;
    private WeakReference<f> mWeakListener = null;

    private native int nativeGetBitsPerChannel();

    private native int nativeGetChannels();

    private native int nativeGetCurDurationMS();

    private native int nativeGetCurPtsMS();

    private native int nativeGetDurationMS(String str);

    private native int nativeGetSampleRate();

    private native void nativePause();

    private native void nativeResume();

    private native int nativeSetCurPtsMS(int i);

    private native void nativeSetPitch(float f);

    private native void nativeSetVolume(float f);

    private native boolean nativeStartPlay(String str, TXCLiveBGMPlayer tXCLiveBGMPlayer);

    private native void nativeStopPlay();

    static {
        d.e();
    }

    public static TXCLiveBGMPlayer getInstance() {
        if (instance == null) {
            synchronized (TXCLiveBGMPlayer.class) {
                if (instance == null) {
                    instance = new TXCLiveBGMPlayer();
                }
            }
        }
        return instance;
    }

    private TXCLiveBGMPlayer() {
    }

    public synchronized void setOnPlayListener(f fVar) {
        if (fVar == null) {
            this.mWeakListener = null;
        }
        this.mWeakListener = new WeakReference<>(fVar);
    }

    public void setContext(Context context) {
        this.mContext = context;
    }

    public boolean startPlay(String str) {
        if (str == null || str.isEmpty()) {
            TXCLog.e(TAG, "start live bgm failed! invalid params!");
            return false;
        }
        stopPlay();
        this.mFilePath = str;
        this.mIsRunning = true;
        if (!nativeStartPlay(this.mFilePath, this)) {
            onPlayEnd(-1);
            return false;
        }
        TXCTraeJNI.traeStartPlay(this.mContext);
        onPlayStart();
        String str2 = TAG;
        TXCLog.i(str2, "start bgm play : filePath = " + str);
        return true;
    }

    public boolean stopPlay() {
        this.mIsRunning = false;
        long currentTimeMillis = System.currentTimeMillis();
        nativeStopPlay();
        TXCTraeJNI.traeStopPlay();
        this.mFilePath = null;
        this.mContext = null;
        this.mIsPause = false;
        String str = TAG;
        TXCLog.i(str, "stopBGMPlay cost(MS): " + (System.currentTimeMillis() - currentTimeMillis));
        return true;
    }

    public boolean isRunning() {
        return this.mIsRunning && !this.mIsPause;
    }

    public boolean isPlaying() {
        return this.mIsRunning;
    }

    public boolean pause() {
        TXCLog.i(TAG, "pause");
        this.mIsPause = true;
        nativePause();
        return true;
    }

    public boolean resume() {
        TXCLog.i(TAG, "resume");
        this.mIsPause = false;
        nativeResume();
        return true;
    }

    public boolean setVolume(float f) {
        nativeSetVolume(f);
        return true;
    }

    public int getBGMDuration(String str) {
        if (str == null) {
            return nativeGetCurDurationMS();
        }
        return nativeGetDurationMS(str);
    }

    public int setBGMPosition(int i) {
        if (i < getBGMDuration(null)) {
            return nativeSetCurPtsMS(i);
        }
        TXCLog.e(TAG, "setMusicPosition with position out of current music duration , finish play!");
        stopPlay();
        onPlayEnd(0);
        return 0;
    }

    public void setPitch(float f) {
        nativeSetPitch(f);
    }

    private void onPlayStart() {
        final f fVar;
        synchronized (this) {
            fVar = this.mWeakListener != null ? this.mWeakListener.get() : null;
        }
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            /* class com.tencent.liteav.audio.TXCLiveBGMPlayer.AnonymousClass1 */

            public void run() {
                f fVar = fVar;
                if (fVar != null) {
                    fVar.a();
                }
            }
        });
    }

    private void onPlayEnd(final int i) {
        final f fVar;
        synchronized (this) {
            fVar = this.mWeakListener != null ? this.mWeakListener.get() : null;
        }
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            /* class com.tencent.liteav.audio.TXCLiveBGMPlayer.AnonymousClass2 */

            public void run() {
                f fVar = fVar;
                if (fVar != null) {
                    fVar.a(i);
                }
            }
        });
    }

    private void onPlayProgress(long j, long j2) {
        f fVar;
        synchronized (this) {
            fVar = this.mWeakListener != null ? this.mWeakListener.get() : null;
        }
        if (fVar != null) {
            fVar.a(j, j2);
        }
    }

    private void nativeOPlayProgress(long j, long j2) {
        onPlayProgress(j, j2);
        if (j == j2) {
            onPlayEnd(0);
        }
    }
}
