package com.tencent.liteav.audio.impl;

import com.tencent.liteav.audio.c;
import com.tencent.liteav.audio.d;
import com.tencent.liteav.basic.e.b;
import com.tencent.liteav.basic.log.TXCLog;
import java.lang.ref.WeakReference;

public class TXCJitter {
    private static final String TAG = "TXCJitter";
    private static WeakReference<d> mAudioCoreDataListener = null;
    protected float mAutoAdjustMaxCache = 5.0f;
    protected float mAutoAdjustMinCache = 1.0f;
    protected float mCacheTime = 5.0f;
    protected WeakReference<d> mDataListener;
    protected boolean mEnableVolumeLevelCal = false;
    protected WeakReference<c> mEventListener;
    protected boolean mIsAutoAdjustCache = true;
    protected boolean mIsPlayMute = false;
    protected volatile boolean mIsPlaying = false;
    protected boolean mIsRealTimePlay = false;
    protected long mJitterBuffer = 0;
    protected boolean mMuteInSpeaker = false;
    protected int mPlayVolume = 100;
    protected int mSmoothMode = 0;
    protected String mUserID = null;

    public static native void nativeEnableCoreplayVolumeLevelCal(boolean z);

    public static native int nativeGetCorePlayVolumeLevel();

    public static native boolean nativeIsTracksEmpty();

    public static native void nativePlayAfterCorePlayCallback(byte[] bArr, int i);

    public static native void nativeSetCorePlayListener(boolean z);

    public static native boolean nativeStopAllTracks();

    /* access modifiers changed from: protected */
    public native long nativeCreateJitterBuffer(TXCJitter tXCJitter, boolean z);

    /* access modifiers changed from: protected */
    public native void nativeDestoryJitterBuffer(long j);

    /* access modifiers changed from: protected */
    public native void nativeEnableAutoAdjustCache(long j, boolean z);

    /* access modifiers changed from: protected */
    public native void nativeEnableVolumeLevelCal(long j, boolean z);

    /* access modifiers changed from: protected */
    public native int nativeGetVolumeLevel(long j);

    /* access modifiers changed from: protected */
    public native void nativeMuteInSpeaker(long j, boolean z);

    /* access modifiers changed from: protected */
    public native void nativeSetAutoAdjustMaxCache(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetAutoAdjustMinCache(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetCacheTime(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetJitterCycle(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetJitterDataListener(boolean z);

    /* access modifiers changed from: protected */
    public native void nativeSetLoadingThreshold(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetMute(long j, boolean z);

    /* access modifiers changed from: protected */
    public native void nativeSetRtcPlayHungryTimeThreshold(long j, int i);

    /* access modifiers changed from: protected */
    public native void nativeSetUserID(long j, String str);

    /* access modifiers changed from: protected */
    public native void nativeSetVolume(long j, int i);

    static {
        com.tencent.liteav.basic.util.d.e();
    }

    public TXCJitter(String str) {
        this.mUserID = str;
    }

    /* access modifiers changed from: protected */
    public void finalize() {
        long j = this.mJitterBuffer;
        if (j != 0) {
            nativeDestoryJitterBuffer(j);
            this.mJitterBuffer = 0;
        }
    }

    public static void setAudioCorePlayListener(d dVar) {
        mAudioCoreDataListener = new WeakReference<>(dVar);
        StringBuilder sb = new StringBuilder();
        sb.append(" setAudioCorePlayListener: ");
        boolean z = false;
        sb.append(dVar != null);
        TXCLog.i(TAG, sb.toString());
        if (dVar != null) {
            z = true;
        }
        nativeSetCorePlayListener(z);
    }

    public static void onCorePlayPcmData(byte[] bArr, long j, int i, int i2) {
        d dVar;
        WeakReference<d> weakReference = mAudioCoreDataListener;
        if (weakReference != null && (dVar = weakReference.get()) != null) {
            dVar.a(null, bArr, j, i, i2);
        }
    }

    public void setCacheTime(float f) {
        TXCLog.i(TAG, "set cache time to " + f);
        if (this.mJitterBuffer == 0) {
            this.mCacheTime = f;
        }
    }

    public void enableAutojustCache(boolean z) {
        TXCLog.i(TAG, "set auto adjust cache to " + z);
        if (this.mJitterBuffer == 0) {
            this.mIsAutoAdjustCache = z;
        }
    }

    public void setAutoAdjustMaxCache(float f) {
        TXCLog.i(TAG, "set auto adjust max cache to " + f);
        if (this.mJitterBuffer == 0) {
            this.mAutoAdjustMaxCache = f;
        }
    }

    public void setAutoAdjustMinCache(float f) {
        TXCLog.i(TAG, "set auto adjust min cache to " + f);
        if (this.mJitterBuffer == 0) {
            this.mAutoAdjustMinCache = f;
        }
    }

    public void enableRealTimePlay(boolean z) {
        if (z != this.mIsRealTimePlay) {
            TXCLog.i(TAG, "set real-time play to " + z);
            if (this.mJitterBuffer == 0) {
                this.mIsRealTimePlay = z;
            }
        }
    }

    public void setUserID(String str) {
        this.mUserID = str;
    }

    public void enableVolumeLevelCal(boolean z) {
        this.mEnableVolumeLevelCal = z;
        long j = this.mJitterBuffer;
        if (j != 0) {
            nativeEnableVolumeLevelCal(j, z);
        }
    }

    public int getVolumeLevel() {
        long j = this.mJitterBuffer;
        if (j == 0 || !this.mEnableVolumeLevelCal) {
            return 0;
        }
        return nativeGetVolumeLevel(j);
    }

    public boolean isPlaying() {
        return this.mIsPlaying;
    }

    public int startPlay() {
        this.mIsPlaying = true;
        if (this.mJitterBuffer != 0) {
            return 0;
        }
        this.mJitterBuffer = nativeCreateJitterBuffer(this, this.mIsRealTimePlay);
        long j = this.mJitterBuffer;
        if (j != 0) {
            nativeSetUserID(j, this.mUserID);
            nativeSetCacheTime(this.mJitterBuffer, this.mCacheTime);
            nativeEnableAutoAdjustCache(this.mJitterBuffer, this.mIsAutoAdjustCache);
            nativeSetAutoAdjustMaxCache(this.mJitterBuffer, this.mAutoAdjustMaxCache);
            nativeSetAutoAdjustMinCache(this.mJitterBuffer, this.mAutoAdjustMinCache);
            nativeSetMute(this.mJitterBuffer, this.mIsPlayMute);
            nativeMuteInSpeaker(this.mJitterBuffer, this.mMuteInSpeaker);
            nativeEnableVolumeLevelCal(this.mJitterBuffer, this.mEnableVolumeLevelCal);
            nativeSetJitterCycle(this.mJitterBuffer, b.a().a("Audio", "LIVE_JitterCycle"));
            nativeSetLoadingThreshold(this.mJitterBuffer, b.a().a("Audio", "LoadingThreshold"));
            nativeSetRtcPlayHungryTimeThreshold(this.mJitterBuffer, (int) b.a().a("Audio", "RtcPlayHungryTimeThreshold"));
        } else {
            TXCLog.e(TAG, "soft dec, create jitterbuffer failed!!");
        }
        TXCLog.e(TAG, "soft dec, create jitterbuffer with id " + this.mJitterBuffer);
        return 0;
    }

    public int stopPlay() {
        this.mIsPlaying = false;
        long j = this.mJitterBuffer;
        if (j != 0) {
            nativeDestoryJitterBuffer(j);
            this.mJitterBuffer = 0;
        }
        this.mEventListener = null;
        this.mDataListener = null;
        this.mCacheTime = 5.0f;
        this.mIsAutoAdjustCache = true;
        this.mAutoAdjustMaxCache = 5.0f;
        this.mAutoAdjustMinCache = 1.0f;
        this.mIsRealTimePlay = false;
        this.mIsPlayMute = false;
        this.mMuteInSpeaker = false;
        this.mSmoothMode = 0;
        this.mUserID = null;
        return 0;
    }

    public void setPlayMute(boolean z) {
        long j = this.mJitterBuffer;
        if (!(j == 0 || z == this.mIsPlayMute)) {
            nativeSetMute(j, z);
        }
        TXCLog.i(TAG, "set mute to " + z);
        this.mIsPlayMute = z;
    }

    public void muteInSpeaker(boolean z) {
        if (z != this.mMuteInSpeaker) {
            this.mMuteInSpeaker = z;
            long j = this.mJitterBuffer;
            if (j != 0) {
                nativeMuteInSpeaker(j, z);
            }
        }
    }

    public void setPlayVolume(int i) {
        long j = this.mJitterBuffer;
        if (!(j == 0 || i == this.mPlayVolume)) {
            nativeSetVolume(j, i);
        }
        TXCLog.i(TAG, "set volume to " + i);
        this.mPlayVolume = i;
    }

    public void setDataListener(d dVar) {
        this.mDataListener = new WeakReference<>(dVar);
        StringBuilder sb = new StringBuilder();
        sb.append(" setDataListener: ");
        boolean z = false;
        sb.append(dVar != null);
        TXCLog.i(TAG, sb.toString());
        if (dVar != null) {
            z = true;
        }
        nativeSetJitterDataListener(z);
    }

    public void onAudioPlayPcmData(byte[] bArr, long j, int i, int i2) {
        d dVar;
        WeakReference<d> weakReference = this.mDataListener;
        if (weakReference != null && (dVar = weakReference.get()) != null) {
            dVar.a(this.mUserID, bArr, j, i, i2);
        }
    }

    public void setEventListener(c cVar) {
        this.mEventListener = new WeakReference<>(cVar);
        StringBuilder sb = new StringBuilder();
        sb.append(" setEventListener: ");
        sb.append(cVar != null);
        TXCLog.i(TAG, sb.toString());
    }

    public void onAudioJitterBufferError(int i, String str) {
        c cVar;
        WeakReference<c> weakReference = this.mEventListener;
        if (weakReference != null && (cVar = weakReference.get()) != null) {
            cVar.a(this.mUserID, i, str);
        }
    }

    public void onAudioJitterBufferNotify(int i, String str) {
        if (this.mEventListener != null) {
            TXCLog.e(TAG, "onAudioJitterBufferNotify  cur state " + i);
            c cVar = this.mEventListener.get();
            if (cVar != null) {
                cVar.b(this.mUserID, i, str);
            }
        }
    }

    public static int GetCorePlayVolumeLevel() {
        return nativeGetCorePlayVolumeLevel();
    }

    public static void EnableCoreplayVolumeLevelCal(boolean z) {
        nativeEnableCoreplayVolumeLevelCal(z);
    }
}
