package com.tencent.liteav.basic.datareport;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.os.Build;
import android.os.Environment;
import android.provider.Settings;
import android.telephony.TelephonyManager;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.util.TXCCommonUtil;
import com.tencent.liteav.basic.util.TXCTimeUtil;
import com.tencent.liteav.basic.util.d;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.security.MessageDigest;
import java.util.UUID;

public class TXCDRApi {
    private static final char[] DIGITS_LOWER = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
    static final int NETWORK_TYPE_2G = 4;
    static final int NETWORK_TYPE_3G = 3;
    static final int NETWORK_TYPE_4G = 2;
    static final int NETWORK_TYPE_UNKNOWN = 255;
    static final int NETWORK_TYPE_WIFI = 1;
    private static String g_simulate_idfa = "";
    static boolean initRpt = false;
    private static String mAppName = "";
    private static String mDevId = "";
    private static String mDevType = "";
    private static String mDevUUID = "";
    private static String mNetType = "";
    private static String mSysVersion = "";

    public static native int nativeGetStatusReportInterval();

    private static native void nativeInitDataReport();

    private static native void nativeInitEventInternal(String str, int i, int i2, TXCDRExtInfo tXCDRExtInfo);

    public static native void nativeReportAVRoomEvent(int i, long j, String str, int i2, int i3, String str2, String str3);

    private static native void nativeReportDAUInterval(int i, int i2, String str);

    public static native void nativeReportEvent(String str, int i);

    public static native void nativeReportEvent40003(String str, int i, int i2, String str2, String str3);

    public static native void nativeSetCommonValue(String str, String str2);

    private static native void nativeSetEventValueInterval(String str, int i, String str2, String str3);

    private static native void nativeUninitDataReport();

    public static void InitEvent(Context context, String str, int i, int i2, TXCDRExtInfo tXCDRExtInfo) {
        setCommonInfo(context);
        if (str != null) {
            nativeInitEventInternal(str, i, i2, tXCDRExtInfo);
        }
    }

    public static void txSetEventValue(String str, int i, String str2, String str3) {
        nativeSetEventValueInterval(str, i, str2, str3);
    }

    public static void txSetEventIntValue(String str, int i, String str2, long j) {
        nativeSetEventValueInterval(str, i, str2, "" + j);
    }

    public static void txReportDAU(Context context, int i) {
        if (context != null) {
            setCommonInfo(context);
        }
        nativeReportDAUInterval(i, 0, "");
    }

    public static void txReportDAU(Context context, int i, int i2, String str) {
        if (context != null) {
            setCommonInfo(context);
        }
        nativeReportDAUInterval(i, i2, str);
    }

    public static void reportEvent40003(String str, int i, int i2, String str2, String str3) {
        nativeReportEvent40003(str, i, i2, str2, str3);
    }

    public static void reportAVRoomEvent(int i, long j, String str, int i2, int i3, String str2, String str3) {
        nativeReportAVRoomEvent(i, j, str, i2, i3, str2, str3);
    }

    public static int getStatusReportInterval() {
        return nativeGetStatusReportInterval();
    }

    public static void setCommonInfo(Context context) {
        mDevType = Build.MODEL;
        mNetType = Integer.toString(getNetworkType(context));
        if (mDevId.isEmpty()) {
            mDevId = getSimulateIDFA(context);
        }
        if (mDevUUID.isEmpty()) {
            mDevUUID = getDevUUID(context, mDevId);
        }
        String packageName = getPackageName(context);
        mAppName = getApplicationNameByPackageName(context, packageName) + ":" + packageName;
        mSysVersion = String.valueOf(Build.VERSION.SDK_INT);
        txSetCommonInfo();
    }

    public static void txSetCommonInfo() {
        if (mDevType != null) {
            nativeSetCommonValue(a.f, mDevType);
        }
        if (mNetType != null) {
            nativeSetCommonValue(a.g, mNetType);
        }
        if (mDevId != null) {
            nativeSetCommonValue(a.h, mDevId);
        }
        if (mDevUUID != null) {
            nativeSetCommonValue(a.i, mDevUUID);
        }
        if (mAppName != null) {
            nativeSetCommonValue(a.j, mAppName);
        }
        if (mSysVersion != null) {
            nativeSetCommonValue(a.l, mSysVersion);
        }
    }

    public static void txSetAppVersion(String str) {
        if (str != null) {
            nativeSetCommonValue(a.k, str);
        }
    }

    public static String txCreateToken() {
        return UUID.randomUUID().toString();
    }

    private static String byteArrayToHexString(byte[] bArr) {
        char[] cArr = new char[(bArr.length << 1)];
        int i = 0;
        for (int i2 = 0; i2 < bArr.length; i2++) {
            int i3 = i + 1;
            char[] cArr2 = DIGITS_LOWER;
            cArr[i] = cArr2[(bArr[i2] & 240) >>> 4];
            i = i3 + 1;
            cArr[i3] = cArr2[bArr[i2] & 15];
        }
        return new String(cArr);
    }

    static {
        d.e();
        nativeInitDataReport();
    }

    public static String string2Md5(String str) {
        String str2;
        if (str == null) {
            return "";
        }
        try {
            str2 = byteArrayToHexString(MessageDigest.getInstance("MD5").digest(str.getBytes("UTF-8")));
        } catch (Exception e) {
            e.printStackTrace();
            str2 = "";
        }
        if (str2 == null) {
            return "";
        }
        return str2;
    }

    public static String doRead(Context context) {
        String str = "";
        try {
            TelephonyManager telephonyManager = (TelephonyManager) context.getSystemService("phone");
            String deviceId = telephonyManager != null ? telephonyManager.getDeviceId() : str;
            if (deviceId != null) {
                str = deviceId;
            }
        } catch (Exception unused) {
        }
        TXCLog.d("rtmpsdk", "deviceinfo:" + str);
        return string2Md5(str);
    }

    public static String getOrigAndroidID(Context context) {
        String str;
        try {
            str = Settings.Secure.getString(context.getContentResolver(), "android_id");
        } catch (Throwable unused) {
            str = "";
        }
        return string2Md5(str);
    }

    public static String getOrigMacAddr(Context context) {
        String str;
        try {
            WifiManager wifiManager = (WifiManager) context.getSystemService("wifi");
            WifiInfo connectionInfo = wifiManager != null ? wifiManager.getConnectionInfo() : null;
            str = connectionInfo != null ? connectionInfo.getMacAddress() : null;
            if (str != null) {
                try {
                    str = string2Md5(str.replaceAll(":", "").toUpperCase());
                } catch (Exception unused) {
                }
            }
        } catch (Exception unused2) {
            str = "";
        }
        if (str == null) {
            return "";
        }
        return str;
    }

    /* JADX WARNING: Removed duplicated region for block: B:35:0x00ad A[LOOP:0: B:33:0x00a8->B:35:0x00ad, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00de A[LOOP:1: B:37:0x00dc->B:38:0x00de, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x0178 A[Catch:{ Exception -> 0x01b0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x019d A[Catch:{ Exception -> 0x01b0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x00db A[EDGE_INSN: B:60:0x00db->B:36:0x00db ?: BREAK  , SYNTHETIC] */
    public static String getSimulateIDFA(Context context) {
        String str;
        File file;
        File file2;
        long currentTimeMillis;
        int i;
        int i2;
        int i3;
        Exception e;
        String str2 = g_simulate_idfa;
        if (str2 != null && str2.length() > 0) {
            return g_simulate_idfa;
        }
        SharedPreferences sharedPreferences = context.getSharedPreferences("com.tencent.liteav.dev_uuid", 0);
        String str3 = "";
        String string = sharedPreferences.getString("com.tencent.liteav.key_dev_uuid", str3);
        String str4 = null;
        try {
            File file3 = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/txrtmp/spuid");
            if (file3.exists()) {
                FileInputStream fileInputStream = new FileInputStream(file3);
                int available = fileInputStream.available();
                if (available > 0) {
                    byte[] bArr = new byte[available];
                    fileInputStream.read(bArr);
                    str = new String(bArr, "UTF-8");
                } else {
                    str = null;
                }
                try {
                    fileInputStream.close();
                } catch (Exception e2) {
                    e = e2;
                }
            } else {
                str = null;
            }
        } catch (Exception e3) {
            e = e3;
            str = null;
            TXCLog.e("TXCDRApi", "read UUID from file failed! reason: " + e.getMessage());
            if (string == null) {
            }
            str4 = str;
            currentTimeMillis = System.currentTimeMillis();
            long timeTick = TXCTimeUtil.getTimeTick();
            String b = d.b(context);
            i = 5;
            while (true) {
                i2 = 1;
                if (i >= 0) {
                }
                str3 = str3 + String.format("%02x", Byte.valueOf((byte) ((int) ((currentTimeMillis >> (i * 8)) & 255))));
                i--;
                currentTimeMillis = currentTimeMillis;
            }
            i3 = 3;
            while (i3 >= 0) {
            }
            StringBuilder sb = new StringBuilder();
            sb.append(str3);
            sb.append(string2Md5(b + UUID.randomUUID().toString()));
            str4 = sb.toString();
            g_simulate_idfa = str4;
            TXCLog.i("TXCDRApi", "UUID:" + g_simulate_idfa);
            try {
                file = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/txrtmp");
                if (!file.exists()) {
                }
                file2 = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/txrtmp/spuid");
                if (!file2.exists()) {
                }
                FileOutputStream fileOutputStream = new FileOutputStream(file2);
                fileOutputStream.write(str4.getBytes());
                fileOutputStream.close();
            } catch (Exception e4) {
                TXCLog.e("TXCDRApi", "write UUID to file failed! reason: " + e4.getMessage());
            }
            SharedPreferences.Editor edit = sharedPreferences.edit();
            edit.putString("com.tencent.liteav.key_dev_uuid", str4);
            edit.commit();
            return g_simulate_idfa;
        }
        if (string == null && string.length() > 0) {
            str4 = string;
        } else if (str != 0 && str.length() > 0) {
            str4 = str;
        }
        if (str4 == null || str4.length() == 0) {
            currentTimeMillis = System.currentTimeMillis();
            long timeTick2 = TXCTimeUtil.getTimeTick();
            String b2 = d.b(context);
            i = 5;
            while (true) {
                i2 = 1;
                if (i >= 0) {
                    break;
                }
                str3 = str3 + String.format("%02x", Byte.valueOf((byte) ((int) ((currentTimeMillis >> (i * 8)) & 255))));
                i--;
                currentTimeMillis = currentTimeMillis;
            }
            i3 = 3;
            while (i3 >= 0) {
                StringBuilder sb2 = new StringBuilder();
                sb2.append(str3);
                Object[] objArr = new Object[i2];
                objArr[0] = Byte.valueOf((byte) ((int) ((timeTick2 >> (i3 * 8)) & 255)));
                sb2.append(String.format("%02x", objArr));
                str3 = sb2.toString();
                i3--;
                i2 = 1;
            }
            StringBuilder sb3 = new StringBuilder();
            sb3.append(str3);
            sb3.append(string2Md5(b2 + UUID.randomUUID().toString()));
            str4 = sb3.toString();
        }
        g_simulate_idfa = str4;
        TXCLog.i("TXCDRApi", "UUID:" + g_simulate_idfa);
        if (str == null || !str.equals(str4)) {
            file = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/txrtmp");
            if (!file.exists()) {
                file.mkdir();
            }
            file2 = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/txrtmp/spuid");
            if (!file2.exists()) {
                file2.createNewFile();
            }
            FileOutputStream fileOutputStream2 = new FileOutputStream(file2);
            fileOutputStream2.write(str4.getBytes());
            fileOutputStream2.close();
        }
        if (string == null || !string.equals(str4)) {
            SharedPreferences.Editor edit2 = sharedPreferences.edit();
            edit2.putString("com.tencent.liteav.key_dev_uuid", str4);
            edit2.commit();
        }
        return g_simulate_idfa;
    }

    public static String getDevUUID(Context context, String str) {
        return getSimulateIDFA(context);
    }

    public static int getNetworkType(Context context) {
        if (context == null) {
            return 255;
        }
        TelephonyManager telephonyManager = (TelephonyManager) context.getSystemService("phone");
        NetworkInfo activeNetworkInfo = ((ConnectivityManager) context.getSystemService("connectivity")).getActiveNetworkInfo();
        if (activeNetworkInfo == null) {
            return 255;
        }
        if (activeNetworkInfo.getType() == 1) {
            return 1;
        }
        if (activeNetworkInfo.getType() != 0) {
            return 255;
        }
        switch (telephonyManager.getNetworkType()) {
            case 1:
            case 2:
            case 4:
            case 7:
            case 11:
                return 4;
            case 3:
            case 5:
            case 6:
            case 8:
            case 9:
            case 10:
            case 12:
            case 14:
            case 15:
                return 3;
            case 13:
            default:
                return 2;
        }
    }

    private static String getPackageName(Context context) {
        try {
            return context.getPackageManager().getPackageInfo(context.getPackageName(), 0).packageName;
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    public static String getApplicationNameByPackageName(Context context, String str) {
        PackageManager packageManager = context.getPackageManager();
        try {
            return packageManager.getApplicationLabel(packageManager.getApplicationInfo(str, 128)).toString();
        } catch (Exception unused) {
            return "";
        }
    }

    public static void initCrashReport(Context context) {
        String sDKVersionStr;
        try {
            synchronized (TXCDRApi.class) {
                if (!(initRpt || context == null || (sDKVersionStr = TXCCommonUtil.getSDKVersionStr()) == null)) {
                    SharedPreferences.Editor edit = context.getSharedPreferences("BuglySdkInfos", 0).edit();
                    edit.putString("8e50744bf0", sDKVersionStr);
                    edit.commit();
                    initRpt = true;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
