package com.tencent.liteav.videodecoder;

import android.graphics.SurfaceTexture;
import android.os.Bundle;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.view.Surface;
import com.tencent.liteav.TXLiteAVCode;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.module.TXCEventRecorderProxy;
import com.tencent.liteav.basic.module.TXCStatus;
import com.tencent.liteav.basic.structs.TXSNALPacket;
import com.tencent.liteav.basic.structs.TXSVideoFrame;
import com.tencent.liteav.basic.util.TXCTimeUtil;
import com.tencent.liteav.basic.util.d;
import com.tencent.rtmp.TXLiveConstants;
import java.lang.ref.WeakReference;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Iterator;

public class TXCVideoDecoder implements com.tencent.liteav.basic.c.a, c {
    private static final boolean NEW_DECODER = true;
    private static final String TAG = "TXCVideoDecoder";
    private int mDecoderCacheNum;
    private a mDecoderHandler;
    c mDecoderListener;
    private boolean mEnableDecoderChange = false;
    boolean mHWDec = true;
    boolean mHevc = false;
    private ArrayList<TXSNALPacket> mNALList = new ArrayList<>();
    private long mNativeContext;
    boolean mNeedSortFrame = true;
    private WeakReference<com.tencent.liteav.basic.c.a> mNotifyListener;
    private ByteBuffer mPps;
    boolean mRecvFirstFrame = false;
    private boolean mRestarting = false;
    private ByteBuffer mSps;
    private int mStreamType = 0;
    Surface mSurface;
    private String mUserId;
    a mVideoDecoder;
    private int mVideoHeight = 0;
    private int mVideoWidth = 0;

    private native long nativeCreateContext(boolean z);

    private native void nativeDecCache(long j);

    private native void nativeDecodeFrame(long j, byte[] bArr, int i, long j2, long j3, int i2, int i3);

    private native void nativeDestroyContext(long j);

    private native void nativeEnableDecodeChange(long j, boolean z);

    private native void nativeNotifyPts(long j, long j2, int i, int i2);

    private native void nativeSetID(long j, String str);

    private native void nativeSetStreamType(long j, int i);

    @Override // com.tencent.liteav.basic.c.a
    public void onNotifyEvent(int i, Bundle bundle) {
        d.a(this.mNotifyListener, this.mUserId, i, bundle);
    }

    public void setUserId(String str) {
        this.mUserId = str;
        synchronized (this) {
            nativeSetID(this.mNativeContext, this.mUserId);
        }
    }

    public void setStreamType(int i) {
        this.mStreamType = i;
        synchronized (this) {
            nativeSetStreamType(this.mNativeContext, this.mStreamType);
        }
    }

    public void enableChange(boolean z) {
        this.mEnableDecoderChange = z;
        synchronized (this) {
            nativeEnableDecodeChange(this.mNativeContext, this.mEnableDecoderChange);
        }
    }

    public void setListener(c cVar) {
        this.mDecoderListener = cVar;
    }

    public boolean isHardwareDecode() {
        return this.mHWDec;
    }

    public void setNotifyListener(com.tencent.liteav.basic.c.a aVar) {
        this.mNotifyListener = new WeakReference<>(aVar);
    }

    public int setup(SurfaceTexture surfaceTexture, ByteBuffer byteBuffer, ByteBuffer byteBuffer2, boolean z) {
        Surface surface = this.mSurface;
        if (surface != null) {
            surface.release();
            this.mSurface = null;
        }
        return setup(new Surface(surfaceTexture), byteBuffer, byteBuffer2, z);
    }

    public int setup(Surface surface, ByteBuffer byteBuffer, ByteBuffer byteBuffer2, boolean z) {
        this.mSurface = surface;
        this.mSps = byteBuffer;
        this.mPps = byteBuffer2;
        this.mNeedSortFrame = z;
        return 0;
    }

    public void enableHWDec(boolean z) {
        this.mHWDec = z;
    }

    private void addOneNalToDecoder(TXSNALPacket tXSNALPacket) {
        boolean z = tXSNALPacket.nalType == 0;
        Bundle bundle = new Bundle();
        bundle.putBoolean("iframe", z);
        bundle.putByteArray("nal", tXSNALPacket.nalData);
        bundle.putLong("pts", tXSNALPacket.pts);
        bundle.putLong("dts", tXSNALPacket.dts);
        bundle.putInt("codecId", tXSNALPacket.codecId);
        Message message = new Message();
        message.what = 101;
        message.setData(bundle);
        a aVar = this.mDecoderHandler;
        if (aVar != null) {
            aVar.sendMessage(message);
        }
        this.mDecoderCacheNum++;
    }

    private void decNALByNewWay(TXSNALPacket tXSNALPacket) {
        if (this.mHWDec) {
            decodeFrame(tXSNALPacket.nalData, tXSNALPacket.pts, tXSNALPacket.dts, tXSNALPacket.rotation, tXSNALPacket.codecId, 0, 0);
            return;
        }
        synchronized (this) {
            nativeDecodeFrame(this.mNativeContext, tXSNALPacket.nalData, tXSNALPacket.nalType, tXSNALPacket.pts, tXSNALPacket.dts, tXSNALPacket.rotation, tXSNALPacket.codecId);
        }
    }

    private void decNALByOldWay(TXSNALPacket tXSNALPacket) {
        try {
            boolean z = tXSNALPacket.nalType == 0;
            if (this.mRecvFirstFrame || z) {
                if (!this.mRecvFirstFrame && z) {
                    TXCLog.w(TAG, "play:decode: push first i frame");
                    this.mRecvFirstFrame = true;
                }
                if (!this.mRestarting && tXSNALPacket.codecId == 1 && !this.mHWDec) {
                    TXCLog.w(TAG, "play:decode: hevc decode error  ");
                    d.a(this.mNotifyListener, -2304, "h265解码失败");
                    this.mRestarting = true;
                }
                if (this.mDecoderHandler != null) {
                    if (!this.mNALList.isEmpty()) {
                        Iterator<TXSNALPacket> it = this.mNALList.iterator();
                        while (it.hasNext()) {
                            addOneNalToDecoder(it.next());
                        }
                    }
                    this.mNALList.clear();
                    addOneNalToDecoder(tXSNALPacket);
                    return;
                }
                if (z && !this.mNALList.isEmpty()) {
                    this.mNALList.clear();
                }
                this.mNALList.add(tXSNALPacket);
                if (!this.mRestarting) {
                    start();
                    return;
                }
                return;
            }
            TXCLog.i(TAG, "play:decode: push nal ignore p frame when not got i frame");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void pushNAL(TXSNALPacket tXSNALPacket) {
        decNALByNewWay(tXSNALPacket);
    }

    public synchronized int start() {
        if (this.mHWDec && this.mSurface == null) {
            TXCLog.i(TAG, "play:decode: start decoder error when not setup surface, id " + this.mUserId + "_" + this.mStreamType);
            return -1;
        } else if (this.mNativeContext != 0) {
            TXCLog.w(TAG, "play:decode: start decoder error when decoder is started, id " + this.mUserId + "_" + this.mStreamType);
            return -1;
        } else {
            TXCLog.w(TAG, "play:decode: start decoder java id " + this.mUserId + "_" + this.mStreamType);
            this.mNativeContext = nativeCreateContext(this.mHWDec);
            nativeSetID(this.mNativeContext, this.mUserId);
            nativeSetStreamType(this.mNativeContext, this.mStreamType);
            nativeEnableDecodeChange(this.mNativeContext, this.mEnableDecoderChange);
            return 0;
        }
    }

    public synchronized void stop() {
        if (this.mNativeContext == 0) {
            TXCLog.w(TAG, "play:decode: stop decoder ignore when decoder is stopped, id " + this.mUserId + "_" + this.mStreamType);
            return;
        }
        TXCLog.w(TAG, "play:decode: stop decoder java id " + this.mUserId + "_" + this.mStreamType);
        nativeDestroyContext(this.mNativeContext);
        this.mNativeContext = 0;
        this.mNALList.clear();
        this.mRecvFirstFrame = false;
        this.mDecoderCacheNum = 0;
        synchronized (this) {
            if (this.mVideoDecoder != null) {
                this.mVideoDecoder.stop();
                this.mVideoDecoder.setListener(null);
                this.mVideoDecoder.setNotifyListener(null);
                this.mVideoDecoder = null;
            }
            if (this.mSurface != null) {
                this.mSurface.release();
                this.mSurface = null;
            }
        }
    }

    public void restart(boolean z) {
        synchronized (this) {
            this.mHWDec = z;
            this.mNALList.clear();
            int i = 0;
            this.mRecvFirstFrame = false;
            this.mDecoderCacheNum = 0;
            Message obtain = Message.obtain();
            obtain.what = 103;
            obtain.arg1 = this.mHWDec ? 1 : 0;
            if (this.mNeedSortFrame) {
                i = 1;
            }
            obtain.arg2 = i;
            if (this.mDecoderHandler != null) {
                this.mDecoderHandler.sendMessage(obtain);
            }
        }
    }

    public int getDecoderCacheNum() {
        return this.mDecoderCacheNum + this.mNALList.size();
    }

    @Override // com.tencent.liteav.videodecoder.c
    public void onDecodeFrame(TXSVideoFrame tXSVideoFrame, int i, int i2, long j, long j2, int i3) {
        c cVar = this.mDecoderListener;
        if (cVar != null) {
            cVar.onDecodeFrame(tXSVideoFrame, i, i2, j, j2, i3);
        }
        int i4 = this.mDecoderCacheNum;
        if (i4 > 0) {
            this.mDecoderCacheNum = i4 - 1;
        }
        if (tXSVideoFrame == null) {
            synchronized (this) {
                nativeNotifyPts(this.mNativeContext, j, i, i2);
            }
        }
        int GetDecodeCost = this.mVideoDecoder.GetDecodeCost();
        if (this.mHWDec) {
            TXCStatus.a(this.mUserId, 8004, this.mStreamType, Integer.valueOf(GetDecodeCost));
        } else {
            TXCStatus.a(this.mUserId, TXLiteAVCode.EVT_ROOM_REQUEST_AVSEAT_SUCC, this.mStreamType, Integer.valueOf(GetDecodeCost));
        }
    }

    @Override // com.tencent.liteav.videodecoder.c
    public void onVideoSizeChange(int i, int i2) {
        c cVar = this.mDecoderListener;
        if (cVar == null) {
            return;
        }
        if (this.mVideoWidth != i || this.mVideoHeight != i2) {
            this.mVideoWidth = i;
            this.mVideoHeight = i2;
            cVar.onVideoSizeChange(this.mVideoWidth, this.mVideoHeight);
        }
    }

    @Override // com.tencent.liteav.videodecoder.c
    public void onDecodeFailed(int i) {
        c cVar = this.mDecoderListener;
        if (cVar != null) {
            cVar.onDecodeFailed(i);
        }
        synchronized (this) {
            nativeDecCache(this.mNativeContext);
        }
    }

    public boolean isHevc() {
        a aVar = this.mDecoderHandler;
        if (aVar != null) {
            return aVar.a();
        }
        return false;
    }

    private int startDecodeThread() {
        synchronized (this) {
            if (this.mDecoderHandler != null) {
                TXCLog.e(TAG, "play:decode: start decoder error when decoder is started");
                return -1;
            }
            this.mDecoderCacheNum = 0;
            this.mRestarting = false;
            HandlerThread handlerThread = new HandlerThread("VDecoder");
            handlerThread.start();
            if (this.mHWDec) {
                handlerThread.setName("VideoWDec" + handlerThread.getId());
            } else {
                handlerThread.setName("VideoSWDec" + handlerThread.getId());
            }
            a aVar = new a(handlerThread.getLooper());
            aVar.a(this.mHevc, this.mHWDec, this.mSurface, this.mSps, this.mPps, this, this);
            TXCLog.w(TAG, "play:decode: start decode thread");
            Message obtain = Message.obtain();
            obtain.what = 100;
            obtain.obj = Boolean.valueOf(this.mNeedSortFrame);
            aVar.sendMessage(obtain);
            this.mDecoderHandler = aVar;
            return 0;
        }
    }

    private void stopDecodeThread() {
        synchronized (this) {
            if (this.mDecoderHandler != null) {
                this.mDecoderHandler.sendEmptyMessage(102);
            }
            this.mDecoderHandler = null;
        }
    }

    private void notifyDecoderStartEvent(boolean z) {
        TXCEventRecorderProxy.a(this.mUserId, 4005, z ? 1 : 0, -1, "", this.mStreamType);
        Bundle bundle = new Bundle();
        bundle.putInt("EVT_ID", 2008);
        bundle.putLong("EVT_TIME", TXCTimeUtil.getTimeTick());
        bundle.putCharSequence(TXLiveConstants.EVT_DESCRIPTION, z ? "启动硬解" : "启动软解");
        bundle.putInt("EVT_PARAM1", z ? 1 : 2);
        d.a(this.mNotifyListener, this.mUserId, 2008, bundle);
    }

    private boolean hasSurface() {
        return this.mSurface != null;
    }

    static {
        d.e();
    }

    private void onDecodeDone(TXSVideoFrame tXSVideoFrame, int i, int i2, long j, long j2, int i3, int i4) {
        c cVar = this.mDecoderListener;
        if (cVar != null) {
            tXSVideoFrame.width = i;
            tXSVideoFrame.height = i2;
            tXSVideoFrame.rotation = i3;
            tXSVideoFrame.pts = j;
            tXSVideoFrame.frameType = i4;
            cVar.onDecodeFrame(tXSVideoFrame, i, i2, j, j2, i3);
            if (this.mVideoWidth != i || this.mVideoHeight != i2) {
                this.mVideoWidth = i;
                this.mVideoHeight = i2;
                cVar.onVideoSizeChange(this.mVideoWidth, this.mVideoHeight);
            }
        }
    }

    private void decodeFrame(byte[] bArr, long j, long j2, int i, int i2, int i3, int i4) {
        TXSNALPacket tXSNALPacket = new TXSNALPacket();
        tXSNALPacket.nalData = bArr;
        tXSNALPacket.pts = j;
        tXSNALPacket.dts = j2;
        tXSNALPacket.rotation = i;
        tXSNALPacket.codecId = i2;
        synchronized (this) {
            if (this.mNativeContext != 0 && this.mVideoDecoder == null) {
                b bVar = new b();
                bVar.a(i3, i4);
                bVar.setListener(this);
                bVar.setNotifyListener(this.mNotifyListener);
                bVar.config(this.mSurface);
                bVar.start(this.mSps, this.mPps, this.mNeedSortFrame, this.mHevc);
                notifyDecoderStartEvent(true);
                this.mVideoDecoder = bVar;
            }
            if (this.mVideoDecoder != null) {
                this.mVideoDecoder.decode(tXSNALPacket);
            }
        }
    }

    private synchronized void stopHWDecoder() {
        if (this.mVideoDecoder != null) {
            this.mVideoDecoder.stop();
            this.mVideoDecoder.setListener(null);
            this.mVideoDecoder.setNotifyListener(null);
            this.mVideoDecoder = null;
        }
    }

    private void onStartDecoder(boolean z) {
        notifyDecoderStartEvent(z);
    }

    /* access modifiers changed from: private */
    public static class a extends Handler {
        a a;
        c b;
        WeakReference<com.tencent.liteav.basic.c.a> c;
        boolean d;
        boolean e;
        Surface f;
        private ByteBuffer g;
        private ByteBuffer h;

        public a(Looper looper) {
            super(looper);
        }

        public void a(boolean z, boolean z2, Surface surface, ByteBuffer byteBuffer, ByteBuffer byteBuffer2, c cVar, com.tencent.liteav.basic.c.a aVar) {
            this.e = z;
            this.d = z2;
            this.f = surface;
            this.g = byteBuffer;
            this.h = byteBuffer2;
            this.b = cVar;
            this.c = new WeakReference<>(aVar);
        }

        public void handleMessage(Message message) {
            switch (message.what) {
                case 100:
                    a(((Boolean) message.obj).booleanValue());
                    return;
                case 101:
                    try {
                        Bundle data = message.getData();
                        a(data.getByteArray("nal"), data.getLong("pts"), data.getLong("dts"), data.getInt("codecId"));
                        return;
                    } catch (Exception e2) {
                        e2.printStackTrace();
                        return;
                    }
                case 102:
                    b();
                    return;
                case 103:
                    boolean z = false;
                    boolean z2 = message.arg1 == 1;
                    if (message.arg2 == 1) {
                        z = true;
                    }
                    a(z2, z);
                    return;
                default:
                    return;
            }
        }

        public boolean a() {
            a aVar = this.a;
            if (aVar != null) {
                return aVar.isHevc();
            }
            return false;
        }

        private void a(byte[] bArr, long j, long j2, int i) {
            TXSNALPacket tXSNALPacket = new TXSNALPacket();
            tXSNALPacket.nalData = bArr;
            tXSNALPacket.pts = j;
            tXSNALPacket.dts = j2;
            tXSNALPacket.codecId = i;
            a aVar = this.a;
            if (aVar != null) {
                aVar.decode(tXSNALPacket);
            }
        }

        private void b() {
            a aVar = this.a;
            if (aVar != null) {
                aVar.stop();
                this.a.setListener(null);
                this.a.setNotifyListener(null);
                this.a = null;
            }
            Looper.myLooper().quit();
            TXCLog.w(TXCVideoDecoder.TAG, "play:decode: stop decode hwdec: " + this.d);
        }

        private void a(boolean z, boolean z2) {
            this.d = z;
            TXCLog.w(TXCVideoDecoder.TAG, "play:decode: restart decode hwdec: " + this.d);
            a aVar = this.a;
            if (aVar != null) {
                aVar.stop();
                this.a.setListener(null);
                this.a.setNotifyListener(null);
                this.a = null;
            }
            a(z2);
        }

        private void a(boolean z) {
            if (this.a != null) {
                TXCLog.i(TXCVideoDecoder.TAG, "play:decode: start decode ignore hwdec: " + this.d);
                return;
            }
            if (this.d) {
                this.a = new b();
            } else {
                this.a = new TXCVideoFfmpegDecoder();
            }
            this.a.setListener(this.b);
            this.a.setNotifyListener(this.c);
            this.a.config(this.f);
            this.a.start(this.g, this.h, z, this.e);
            TXCLog.w(TXCVideoDecoder.TAG, "play:decode: start decode hwdec: " + this.d + ", hevc: " + this.e);
        }
    }
}
