package com.tencent.rtmp;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.Surface;
import android.view.TextureView;
import com.tencent.liteav.basic.c.a;
import com.tencent.liteav.basic.datareport.TXCDRApi;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.util.TXCCommonUtil;
import com.tencent.liteav.basic.util.TXCTimeUtil;
import com.tencent.liteav.c;
import com.tencent.liteav.network.f;
import com.tencent.liteav.network.g;
import com.tencent.liteav.network.i;
import com.tencent.liteav.txcvodplayer.TextureRenderView;
import com.tencent.rtmp.TXLivePlayer;
import com.tencent.rtmp.ui.TXCloudVideoView;
import java.util.ArrayList;

public class TXVodPlayer implements a, g {
    public static final int PLAYER_TYPE_EXO = 1;
    public static final int PLAYER_TYPE_FFPLAY = 0;
    public static final String TAG = "TXVodPlayer";
    private boolean mAutoPlay = true;
    private int mBitrateIndex;
    private TXVodPlayConfig mConfig;
    private Context mContext;
    private boolean mEnableHWDec = false;
    private boolean mIsGetPlayInfo;
    private boolean mIsNeedClearLastImg = true;
    private ITXLivePlayListener mListener = null;
    private boolean mLoop;
    private boolean mMirror;
    private boolean mMute = false;
    private f mNetApi;
    private ITXVodPlayListener mNewListener = null;
    private String mPlayUrl = "";
    private com.tencent.liteav.f mPlayer;
    private float mRate = 1.0f;
    private int mRenderMode;
    private int mRenderRotation;
    private boolean mSnapshotRunning = false;
    protected float mStartTime;
    private Surface mSurface;
    private TXCloudVideoView mTXCloudVideoView;
    private TextureRenderView mTextureView;
    private String mToken;

    public TXVodPlayer(Context context) {
        this.mContext = context.getApplicationContext();
        TXCCommonUtil.setAppContext(this.mContext);
        TXCLog.init();
    }

    public void setConfig(TXVodPlayConfig tXVodPlayConfig) {
        this.mConfig = tXVodPlayConfig;
        if (this.mConfig == null) {
            this.mConfig = new TXVodPlayConfig();
        }
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            c q = fVar.q();
            if (q == null) {
                q = new c();
            }
            q.e = this.mConfig.mConnectRetryCount;
            q.f = this.mConfig.mConnectRetryInterval;
            q.q = this.mConfig.mTimeout;
            q.h = this.mEnableHWDec;
            q.m = this.mConfig.mCacheFolderPath;
            q.n = this.mConfig.mMaxCacheItems;
            q.o = this.mConfig.mPlayerType;
            q.p = this.mConfig.mHeaders;
            q.r = this.mConfig.enableAccurateSeek;
            q.s = this.mConfig.autoRotate;
            q.t = this.mConfig.smoothSwitchBitrate;
            q.u = this.mConfig.cacheMp4ExtName;
            q.v = this.mConfig.progressInterval;
            q.w = this.mConfig.maxBufferSize;
            this.mPlayer.a(q);
        }
    }

    public void setPlayerView(TXCloudVideoView tXCloudVideoView) {
        this.mTXCloudVideoView = tXCloudVideoView;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a(tXCloudVideoView);
        }
    }

    public void setPlayerView(TextureRenderView textureRenderView) {
        this.mTextureView = textureRenderView;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a(textureRenderView);
        }
    }

    public void setSurface(Surface surface) {
        this.mSurface = surface;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a(this.mSurface);
        }
    }

    public int startPlay(String str) {
        String path;
        if (str == null || TextUtils.isEmpty(str)) {
            return -1;
        }
        TXCDRApi.initCrashReport(this.mContext);
        int i = this.mBitrateIndex;
        stopPlay(this.mIsNeedClearLastImg);
        this.mBitrateIndex = i;
        if (!(this.mToken == null || (path = Uri.parse(str).getPath()) == null)) {
            String[] split = path.split("/");
            if (split.length > 0) {
                int lastIndexOf = str.lastIndexOf(split[split.length - 1]);
                str = str.substring(0, lastIndexOf) + "voddrm.token." + this.mToken + "." + str.substring(lastIndexOf);
            }
        }
        this.mPlayUrl = checkPlayUrl(str);
        TXCLog.i(TAG, "===========================================================================================================================================================");
        TXCLog.i(TAG, "===========================================================================================================================================================");
        TXCLog.i(TAG, "=====  StartPlay url = " + this.mPlayUrl + " SDKVersion = " + TXCCommonUtil.getSDKID() + " , " + TXCCommonUtil.getSDKVersionStr() + "    ======");
        TXCLog.i(TAG, "===========================================================================================================================================================");
        TXCLog.i(TAG, "===========================================================================================================================================================");
        this.mPlayer = new com.tencent.liteav.f(this.mContext);
        updateConfig();
        TXCloudVideoView tXCloudVideoView = this.mTXCloudVideoView;
        if (tXCloudVideoView != null) {
            tXCloudVideoView.clearLog();
            this.mTXCloudVideoView.setVisibility(0);
            this.mPlayer.a(this.mTXCloudVideoView);
        } else {
            Surface surface = this.mSurface;
            if (surface != null) {
                this.mPlayer.a(surface);
            } else {
                TextureRenderView textureRenderView = this.mTextureView;
                if (textureRenderView != null) {
                    this.mPlayer.a(textureRenderView);
                }
            }
        }
        this.mPlayer.f(this.mBitrateIndex);
        this.mPlayer.a(this);
        this.mPlayer.e(this.mAutoPlay);
        this.mPlayer.c(this.mStartTime);
        this.mPlayer.a(this.mPlayUrl, 0);
        this.mPlayer.b(this.mMute);
        this.mPlayer.b(this.mRate);
        this.mPlayer.b(this.mRenderRotation);
        this.mPlayer.a(this.mRenderMode);
        this.mPlayer.f(this.mLoop);
        setMirror(this.mMirror);
        return 0;
    }

    public int startPlay(TXPlayerAuthBuilder tXPlayerAuthBuilder) {
        this.mNetApi = new f();
        this.mNetApi.a(tXPlayerAuthBuilder.isHttps);
        this.mNetApi.a(this);
        return this.mNetApi.a(tXPlayerAuthBuilder.appId, tXPlayerAuthBuilder.fileId, tXPlayerAuthBuilder.timeout, tXPlayerAuthBuilder.us, tXPlayerAuthBuilder.exper, tXPlayerAuthBuilder.sign);
    }

    private String checkPlayUrl(String str) {
        if (str.startsWith("http")) {
            try {
                byte[] bytes = str.getBytes("UTF-8");
                StringBuilder sb = new StringBuilder(bytes.length);
                for (int i = 0; i < bytes.length; i++) {
                    int i2 = bytes[i] < 0 ? bytes[i] + 256 : bytes[i];
                    if (!(i2 <= 32 || i2 >= 127 || i2 == 34 || i2 == 37 || i2 == 60 || i2 == 62 || i2 == 91 || i2 == 125 || i2 == 92 || i2 == 93 || i2 == 94 || i2 == 96 || i2 == 123)) {
                        if (i2 != 124) {
                            sb.append((char) i2);
                        }
                    }
                    if (i2 == 37) {
                        TXCLog.w(TAG, "传入URL已转码");
                        return str;
                    }
                    sb.append(String.format("%%%02X", Integer.valueOf(i2 == 1 ? 1 : 0)));
                }
                str = sb.toString();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return str.trim();
    }

    public int stopPlay(boolean z) {
        TXCloudVideoView tXCloudVideoView;
        if (z && (tXCloudVideoView = this.mTXCloudVideoView) != null) {
            tXCloudVideoView.setVisibility(8);
        }
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a(z);
        }
        this.mPlayUrl = "";
        f fVar2 = this.mNetApi;
        if (fVar2 != null) {
            fVar2.a((g) null);
            this.mNetApi = null;
        }
        this.mBitrateIndex = 0;
        this.mIsGetPlayInfo = false;
        return 0;
    }

    public boolean isPlaying() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.c();
        }
        return false;
    }

    public void pause() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a();
        }
    }

    public void resume() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.b();
        }
    }

    public void seek(int i) {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.e(i);
        }
    }

    public void seek(float f) {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a(f);
        }
    }

    public float getCurrentPlaybackTime() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.i();
        }
        return 0.0f;
    }

    public float getBufferDuration() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.j();
        }
        return 0.0f;
    }

    public float getDuration() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.k();
        }
        return 0.0f;
    }

    public float getPlayableDuration() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.l();
        }
        return 0.0f;
    }

    public int getWidth() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.m();
        }
        return 0;
    }

    public int getHeight() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.n();
        }
        return 0;
    }

    @Deprecated
    public void setPlayListener(ITXLivePlayListener iTXLivePlayListener) {
        this.mListener = iTXLivePlayListener;
    }

    public void setVodListener(ITXVodPlayListener iTXVodPlayListener) {
        this.mNewListener = iTXVodPlayListener;
    }

    public void setRenderMode(int i) {
        this.mRenderMode = i;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.a(i);
        }
    }

    public void setRenderRotation(int i) {
        this.mRenderRotation = i;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.b(i);
        }
    }

    public boolean enableHardwareDecode(boolean z) {
        if (z) {
            if (Build.VERSION.SDK_INT < 18) {
                TXCLog.e("HardwareDecode", "enableHardwareDecode failed, android system build.version = " + Build.VERSION.SDK_INT + ", the minimum build.version should be 18(android 4.3 or later)");
                return false;
            } else if (isAVCDecBlacklistDevices()) {
                TXCLog.e("HardwareDecode", "enableHardwareDecode failed, MANUFACTURER = " + Build.MANUFACTURER + ", MODEL" + Build.MODEL);
                return false;
            }
        }
        this.mEnableHWDec = z;
        updateConfig();
        return true;
    }

    public void setMute(boolean z) {
        this.mMute = z;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.b(z);
        }
    }

    public void setAutoPlay(boolean z) {
        this.mAutoPlay = z;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.e(z);
        }
    }

    public void setRate(float f) {
        this.mRate = f;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.b(f);
        }
    }

    public int getBitrateIndex() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.o();
        }
        return 0;
    }

    public void setBitrateIndex(int i) {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.f(i);
        }
        this.mBitrateIndex = i;
    }

    public ArrayList<TXBitrateItem> getSupportedBitrates() {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            return fVar.p();
        }
        return new ArrayList<>();
    }

    public void snapshot(TXLivePlayer.ITXSnapshotListener iTXSnapshotListener) {
        Bitmap bitmap;
        if (!this.mSnapshotRunning && iTXSnapshotListener != null) {
            this.mSnapshotRunning = true;
            com.tencent.liteav.f fVar = this.mPlayer;
            TextureView d = fVar != null ? fVar.d() : null;
            if (d != null) {
                Bitmap bitmap2 = d.getBitmap();
                if (bitmap2 != null) {
                    Matrix transform = d.getTransform(null);
                    if (this.mMirror) {
                        transform.postScale(-1.0f, 1.0f);
                    }
                    bitmap = Bitmap.createBitmap(bitmap2, 0, 0, bitmap2.getWidth(), bitmap2.getHeight(), transform, true);
                    bitmap2.recycle();
                } else {
                    bitmap = bitmap2;
                }
                postBitmapToMainThread(iTXSnapshotListener, bitmap);
                return;
            }
            this.mSnapshotRunning = false;
        }
    }

    public void setMirror(boolean z) {
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.g(z);
        }
        this.mMirror = z;
    }

    public void setStartTime(float f) {
        this.mStartTime = f;
    }

    @Override // com.tencent.liteav.basic.c.a
    public void onNotifyEvent(int i, Bundle bundle) {
        if (i == 15001) {
            TXCloudVideoView tXCloudVideoView = this.mTXCloudVideoView;
            if (tXCloudVideoView != null) {
                tXCloudVideoView.setLogText(bundle, null, 0);
            }
            ITXLivePlayListener iTXLivePlayListener = this.mListener;
            if (iTXLivePlayListener != null) {
                iTXLivePlayListener.onNetStatus(bundle);
            }
            ITXVodPlayListener iTXVodPlayListener = this.mNewListener;
            if (iTXVodPlayListener != null) {
                iTXVodPlayListener.onNetStatus(this, bundle);
                return;
            }
            return;
        }
        TXCloudVideoView tXCloudVideoView2 = this.mTXCloudVideoView;
        if (tXCloudVideoView2 != null) {
            tXCloudVideoView2.setLogText(null, bundle, i);
        }
        ITXLivePlayListener iTXLivePlayListener2 = this.mListener;
        if (iTXLivePlayListener2 != null) {
            iTXLivePlayListener2.onPlayEvent(i, bundle);
        }
        ITXVodPlayListener iTXVodPlayListener2 = this.mNewListener;
        if (iTXVodPlayListener2 != null) {
            iTXVodPlayListener2.onPlayEvent(this, i, bundle);
        }
    }

    private boolean isAVCDecBlacklistDevices() {
        return Build.MANUFACTURER.equalsIgnoreCase("HUAWEI") && Build.MODEL.equalsIgnoreCase("Che2-TL00");
    }

    private void postBitmapToMainThread(final TXLivePlayer.ITXSnapshotListener iTXSnapshotListener, final Bitmap bitmap) {
        if (iTXSnapshotListener != null) {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.tencent.rtmp.TXVodPlayer.AnonymousClass1 */

                public void run() {
                    TXLivePlayer.ITXSnapshotListener iTXSnapshotListener = iTXSnapshotListener;
                    if (iTXSnapshotListener != null) {
                        iTXSnapshotListener.onSnapshot(bitmap);
                    }
                    TXVodPlayer.this.mSnapshotRunning = false;
                }
            });
        }
    }

    /* access modifiers changed from: package-private */
    public void updateConfig() {
        setConfig(this.mConfig);
    }

    @Override // com.tencent.liteav.network.g
    public void onNetSuccess(f fVar) {
        if (fVar == this.mNetApi) {
            i a = fVar.a();
            if (!this.mIsGetPlayInfo) {
                startPlay(a.a());
            }
            this.mIsGetPlayInfo = false;
            Bundle bundle = new Bundle();
            bundle.putInt("EVT_ID", 2010);
            bundle.putLong("EVT_TIME", TXCTimeUtil.getTimeTick());
            bundle.putString(TXLiveConstants.EVT_DESCRIPTION, "文件信息请求成功");
            bundle.putString(TXLiveConstants.EVT_PLAY_URL, a.a());
            bundle.putString(TXLiveConstants.EVT_PLAY_COVER_URL, a.b());
            bundle.putString(TXLiveConstants.EVT_PLAY_NAME, a.f());
            bundle.putString(TXLiveConstants.EVT_PLAY_DESCRIPTION, a.g());
            if (a.d() != null) {
                bundle.putInt(TXLiveConstants.EVT_PLAY_DURATION, a.d().c());
            }
            onNotifyEvent(2010, bundle);
        }
    }

    @Override // com.tencent.liteav.network.g
    public void onNetFailed(f fVar, String str, int i) {
        if (fVar == this.mNetApi) {
            this.mIsGetPlayInfo = false;
            Bundle bundle = new Bundle();
            bundle.putInt("EVT_ID", 2010);
            bundle.putLong("EVT_TIME", TXCTimeUtil.getTimeTick());
            bundle.putString(TXLiveConstants.EVT_DESCRIPTION, str);
            bundle.putInt("EVT_PARAM1", i);
            onNotifyEvent(-2306, bundle);
        }
    }

    public void setToken(String str) {
        this.mToken = str;
    }

    public void setLoop(boolean z) {
        this.mLoop = z;
        com.tencent.liteav.f fVar = this.mPlayer;
        if (fVar != null) {
            fVar.f(this.mLoop);
        }
    }

    public boolean isLoop() {
        return this.mLoop;
    }
}
